@@ -20,7 +20,7 @@ class KBlocksView : public QGraphicsView
     Q_OBJECT
 
 public:
-    explicit KBlocksView(KBlocksScene *scene, QWidget *parent = 0);
+    explicit KBlocksView(KBlocksScene *scene, QWidget *parent = nullptr);
     ~KBlocksView();
 
 signals:
@@ -30,12 +30,12 @@ public slots:
     void settingsChanged();
 
 protected:
-    void focusInEvent(QFocusEvent *event);
-    void focusOutEvent(QFocusEvent *event);
-    void resizeEvent(QResizeEvent *event);
+    void focusInEvent(QFocusEvent *event) override;
+    void focusOutEvent(QFocusEvent *event) override;
+    void resizeEvent(QResizeEvent *event) override;
 
 protected:
-    KBlocksScene *mpGameScene;
+    KBlocksScene *mpGameScene = nullptr;
 };
 
 #endif
