@@ -303,6 +303,8 @@ int gamePlayerMode(KBlocksConfigManager *config, const QApplication &app)
 
 int main(int argc, char *argv[])
 {
+    // Fixes blurry icons with fractional scaling
+    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
     QApplication app(argc, argv);
 
     Kdelibs4ConfigMigrator migrate(QStringLiteral("kblocks"));
